@@ -1,5 +1,12 @@
+#![allow(dead_code)]
+#![allow(unused_imports)]
+
 extern crate sysctl;
-#[cfg(not(target_os = "macos"))]
+
+// Import the trait
+use sysctl::Sysctl;
+
+#[cfg(target_os = "freebsd")]
 fn main() {
     let ctl = match sysctl::Ctl::new("dev.cpu.0.temperature") {
         Ok(c) => c,
@@ -28,5 +35,8 @@ fn main() {
         panic!("Error, not a temperature ctl!")
     }
 }
-#[cfg(target_os = "macos")]
-fn main() {}
+
+#[cfg(not(target_os = "freebsd"))]
+fn main() {
+    println!("This operation is only supported on FreeBSD.");
+}
