@@ -120,6 +120,7 @@ pub fn oidfmt(oid: &[libc::c_int]) -> Result<CtlInfo, SysctlError> {
             Err(e) => return Err(SysctlError::InvalidCStr(e)),
         };
 
+    #[cfg_attr(feature = "cargo-clippy", allow(clippy::redundant_field_names))]
     let s = CtlInfo {
         ctl_type: CtlType::from(ctltype_val),
         fmt: fmt,
@@ -172,11 +173,11 @@ pub fn oidfmt(oid: &[libc::c_int]) -> Result<CtlInfo, SysctlError> {
 }
 
 #[cfg(not(target_os = "macos"))]
-pub fn value_oid(oid: &Vec<i32>) -> Result<CtlValue, SysctlError> {
-    let info: CtlInfo = try!(oidfmt(&oid));
+pub fn value_oid(oid: &[i32]) -> Result<CtlValue, SysctlError> {
+    let info: CtlInfo = oidfmt(&oid)?;
 
     // Check if the value is readable
-    if !(info.flags & CTLFLAG_RD == CTLFLAG_RD) {
+    if info.flags & CTLFLAG_RD != CTLFLAG_RD {
         return Err(SysctlError::NoReadAccess);
     }
 
@@ -241,10 +242,10 @@ pub fn value_oid(oid: &Vec<i32>) -> Result<CtlValue, SysctlError> {
         CtlType::String => match val.len() {
             0 => Ok(CtlValue::String("".to_string())),
             l => std::str::from_utf8(&val[..l - 1])
-                .map_err(|e| SysctlError::Utf8Error(e))
+                .map_err(SysctlError::Utf8Error)
                 .map(|s| CtlValue::String(s.into())),
         },
-        CtlType::S64 => Ok(CtlValue::S64(byteorder::LittleEndian::read_u64(&val))),
+        CtlType::S64 => Ok(CtlValue::S64(byteorder::LittleEndian::read_i64(&val))),
         CtlType::Struct => Ok(CtlValue::Struct(val)),
         CtlType::Uint => Ok(CtlValue::Uint(byteorder::LittleEndian::read_u32(&val))),
         CtlType::Long => Ok(CtlValue::Long(byteorder::LittleEndian::read_i64(&val))),
@@ -262,7 +263,7 @@ pub fn value_oid(oid: &Vec<i32>) -> Result<CtlValue, SysctlError> {
 
 #[cfg(target_os = "macos")]
 pub fn value_oid(oid: &mut Vec<i32>) -> Result<CtlValue, SysctlError> {
-    let info: CtlInfo = try!(oidfmt(&oid));
+    let info: CtlInfo = oidfmt(&oid)?;
 
     // Check if the value is readable
     if !(info.flags & CTLFLAG_RD == CTLFLAG_RD) {
@@ -326,7 +327,7 @@ pub fn value_oid(oid: &mut Vec<i32>) -> Result<CtlValue, SysctlError> {
             Ok(s) => Ok(CtlValue::String(s.into())),
             Err(e) => Err(SysctlError::Utf8Error(e)),
         },
-        CtlType::S64 => Ok(CtlValue::S64(byteorder::LittleEndian::read_u64(&val))),
+        CtlType::S64 => Ok(CtlValue::S64(byteorder::LittleEndian::read_i64(&val))),
         CtlType::Struct => Ok(CtlValue::Struct(val)),
         CtlType::Uint => Ok(CtlValue::Uint(byteorder::LittleEndian::read_u32(&val))),
         CtlType::Long => Ok(CtlValue::Long(byteorder::LittleEndian::read_i64(&val))),
@@ -344,8 +345,8 @@ pub fn value_oid(oid: &mut Vec<i32>) -> Result<CtlValue, SysctlError> {
 }
 
 #[cfg(not(target_os = "macos"))]
-pub fn value_oid_as<T>(oid: &Vec<i32>) -> Result<Box<T>, SysctlError> {
-    let val_enum = try!(value_oid(oid));
+pub fn value_oid_as<T>(oid: &[i32]) -> Result<Box<T>, SysctlError> {
+    let val_enum = value_oid(oid)?;
 
     // Some structs are apparently reported as Node so this check is invalid..
     // let ctl_type = CtlType::from(&val_enum);
@@ -389,7 +390,7 @@ pub fn value_oid_as<T>(oid: &Vec<i32>) -> Result<Box<T>, SysctlError> {
 
 #[cfg(target_os = "macos")]
 pub fn value_oid_as<T>(oid: &mut Vec<i32>) -> Result<Box<T>, SysctlError> {
-    let val_enum = try!(value_oid(oid));
+    let val_enum = value_oid(oid)?;
 
     // Some structs are apparently reported as Node so this check is invalid..
     // let ctl_type = CtlType::from(&val_enum);
@@ -460,11 +461,11 @@ fn value_to_bytes(value: CtlValue) -> Result<Vec<u8>, SysctlError> {
 }
 
 #[cfg(not(target_os = "macos"))]
-pub fn set_oid_value(oid: &Vec<libc::c_int>, value: CtlValue) -> Result<CtlValue, SysctlError> {
-    let info: CtlInfo = try!(oidfmt(&oid));
+pub fn set_oid_value(oid: &[libc::c_int], value: CtlValue) -> Result<CtlValue, SysctlError> {
+    let info: CtlInfo = oidfmt(&oid)?;
 
     // Check if the value is writeable
-    if !(info.flags & CTLFLAG_WR == CTLFLAG_WR) {
+    if info.flags & CTLFLAG_WR != CTLFLAG_WR {
         return Err(SysctlError::NoWriteAccess);
     }
 
@@ -497,7 +498,7 @@ pub fn set_oid_value(oid: &Vec<libc::c_int>, value: CtlValue) -> Result<CtlValue
 
 #[cfg(target_os = "macos")]
 pub fn set_oid_value(oid: &mut Vec<libc::c_int>, value: CtlValue) -> Result<CtlValue, SysctlError> {
-    let info: CtlInfo = try!(oidfmt(&oid));
+    let info: CtlInfo = oidfmt(&oid)?;
 
     // Check if the value is writeable
     if !(info.flags & CTLFLAG_WR == CTLFLAG_WR) {
@@ -533,7 +534,7 @@ pub fn set_oid_value(oid: &mut Vec<libc::c_int>, value: CtlValue) -> Result<CtlV
 }
 
 #[cfg(not(target_os = "macos"))]
-pub fn oid2description(oid: &Vec<libc::c_int>) -> Result<String, SysctlError> {
+pub fn oid2description(oid: &[libc::c_int]) -> Result<String, SysctlError> {
     // Request command for description
     let mut qoid: Vec<libc::c_int> = vec![0, 5];
     qoid.extend(oid);
@@ -563,7 +564,7 @@ pub fn oid2description(oid: &Vec<libc::c_int>) -> Result<String, SysctlError> {
 }
 
 #[cfg(not(target_os = "macos"))]
-pub fn oid2name(oid: &Vec<libc::c_int>) -> Result<String, SysctlError> {
+pub fn oid2name(oid: &[libc::c_int]) -> Result<String, SysctlError> {
     // Request command for name
     let mut qoid: Vec<libc::c_int> = vec![0, 1];
     qoid.extend(oid);
@@ -623,7 +624,7 @@ pub fn oid2name(oid: &Vec<libc::c_int>) -> Result<String, SysctlError> {
 }
 
 #[cfg(not(target_os = "macos"))]
-pub fn next_oid(oid: &Vec<libc::c_int>) -> Result<Option<Vec<libc::c_int>>, SysctlError> {
+pub fn next_oid(oid: &[libc::c_int]) -> Result<Option<Vec<libc::c_int>>, SysctlError> {
     // Request command for next oid
     let mut qoid: Vec<libc::c_int> = vec![0, 2];
     qoid.extend(oid);
@@ -747,7 +748,6 @@ mod tests {
             .expect("Could notget kern.osrevision value type");
         assert_eq!(value_type, crate::CtlType::Int);
     }
-
 }
 
 #[cfg(all(test, target_os = "freebsd"))]
